@@ -23,17 +23,18 @@ import (
 	"time"
 
 	// Inject our fakes
-	fakesharedclient "knative.dev/pkg/client/injection/client/fake"
-	_ "knative.dev/pkg/client/injection/informers/istio/v1alpha3/gateway/fake"
-	_ "knative.dev/pkg/client/injection/informers/istio/v1alpha3/virtualservice/fake"
 	fakekubeclient "knative.dev/pkg/client/injection/kube/client/fake"
 	_ "knative.dev/pkg/client/injection/kube/informers/core/v1/endpoints/fake"
 	_ "knative.dev/pkg/client/injection/kube/informers/core/v1/pod/fake"
 	_ "knative.dev/pkg/client/injection/kube/informers/core/v1/secret/fake"
 	_ "knative.dev/pkg/client/injection/kube/informers/core/v1/service/fake"
+	fakeistioclient "knative.dev/pkg/client/istio/injection/client/fake"
+	_ "knative.dev/pkg/client/istio/injection/informers/networking/v1alpha3/gateway/fake"
+	_ "knative.dev/pkg/client/istio/injection/informers/networking/v1alpha3/virtualservice/fake"
 	fakeservingclient "knative.dev/serving/pkg/client/injection/client/fake"
 	_ "knative.dev/serving/pkg/client/injection/informers/networking/v1alpha1/ingress/fake"
 
+	proto "github.com/gogo/protobuf/proto"
 	"github.com/google/go-cmp/cmp"
 	"golang.org/x/sync/errgroup"
 	corev1 "k8s.io/api/core/v1"
@@ -44,9 +45,10 @@ import (
 	clientgotesting "k8s.io/client-go/testing"
 	"knative.dev/pkg/kmeta"
 
+	istiov1alpha3 "istio.io/api/networking/v1alpha3"
+	"istio.io/client-go/pkg/apis/networking/v1alpha3"
 	"knative.dev/pkg/apis"
 	duckv1 "knative.dev/pkg/apis/duck/v1"
-	"knative.dev/pkg/apis/istio/v1alpha3"
 	"knative.dev/pkg/configmap"
 	"knative.dev/pkg/controller"
 
@@ -78,8 +80,8 @@ var (
 		"gateway.knative-test-gateway": originDomainInternal,
 	}
 	newGateways = map[string]string{
-		"gateway.knative-ingress-gateway": newDomainInternal,
-		"gateway.knative-test-gateway":    originDomainInternal,
+		"gateway." + networking.KnativeIngressGateway: newDomainInternal,
+		"gateway.knative-test-gateway":                originDomainInternal,
 	}
 	defaultMaxRevisionTimeout = time.Duration(apiconfig.DefaultMaxRevisionTimeoutSeconds) * time.Second
 )
@@ -120,43 +122,43 @@ var (
 	}}
 
 	// The gateway server according to ingressTLS.
-	ingressTLSServer = v1alpha3.Server{
+	ingressTLSServer = &istiov1alpha3.Server{
 		Hosts: []string{"host-tls.example.com"},
-		Port: v1alpha3.Port{
+		Port: &istiov1alpha3.Port{
 			Name:     "test-ns/reconciling-ingress:0",
 			Number:   443,
-			Protocol: v1alpha3.ProtocolHTTPS,
+			Protocol: "HTTPS",
 		},
-		TLS: &v1alpha3.TLSOptions{
-			Mode:              v1alpha3.TLSModeSimple,
+		Tls: &istiov1alpha3.Server_TLSOptions{
+			Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
 			ServerCertificate: "tls.crt",
 			PrivateKey:        "tls.key",
 			CredentialName:    "secret0",
 		},
 	}
 
-	ingressHTTPRedirectServer = v1alpha3.Server{
+	ingressHTTPRedirectServer = &istiov1alpha3.Server{
 		Hosts: []string{"*"},
-		Port: v1alpha3.Port{
+		Port: &istiov1alpha3.Port{
 			Name:     "http-server",
 			Number:   80,
-			Protocol: v1alpha3.ProtocolHTTP,
+			Protocol: "HTTP",
 		},
-		TLS: &v1alpha3.TLSOptions{
-			HTTPSRedirect: true,
+		Tls: &istiov1alpha3.Server_TLSOptions{
+			HttpsRedirect: true,
 		},
 	}
 
 	// The gateway server irrelevant to ingressTLS.
-	irrelevantServer = v1alpha3.Server{
+	irrelevantServer = &istiov1alpha3.Server{
 		Hosts: []string{"test.example.com"},
-		Port: v1alpha3.Port{
+		Port: &istiov1alpha3.Port{
 			Name:     "test:0",
 			Number:   443,
-			Protocol: v1alpha3.ProtocolHTTPS,
+			Protocol: "HTTPS",
 		},
-		TLS: &v1alpha3.TLSOptions{
-			Mode:              v1alpha3.TLSModeSimple,
+		Tls: &istiov1alpha3.Server_TLSOptions{
+			Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
 			ServerCertificate: "tls.crt",
 			PrivateKey:        "tls.key",
 			CredentialName:    "other-secret",
@@ -166,30 +168,27 @@ var (
 
 func TestReconcile(t *testing.T) {
 	table := TableTest{{
-		Name:                    "bad workqueue key",
-		Key:                     "too/many/parts",
-		SkipNamespaceValidation: true,
+		Name: "bad workqueue key",
+		Key:  "too/many/parts",
 	}, {
-		Name:                    "key not found",
-		Key:                     "foo/not-found",
-		SkipNamespaceValidation: true,
+		Name: "key not found",
+		Key:  "foo/not-found",
 	}, {
-		Name:                    "skip ingress not matching class key",
-		SkipNamespaceValidation: true,
+		Name: "skip ingress not matching class key",
 		Objects: []runtime.Object{
 			addAnnotations(ingress("no-virtualservice-yet", 1234),
 				map[string]string{networking.IngressClassAnnotationKey: "fake-controller"}),
 		},
 	}, {
-		Name:                    "create VirtualService matching Ingress",
-		SkipNamespaceValidation: true,
+		Name: "create VirtualService matching Ingress",
+
 		Objects: []runtime.Object{
 			ingress("no-virtualservice-yet", 1234),
 		},
 		WantCreates: []runtime.Object{
 			resources.MakeMeshVirtualService(insertProbe(ingress("no-virtualservice-yet", 1234))),
 			resources.MakeIngressVirtualService(insertProbe(ingress("no-virtualservice-yet", 1234)),
-				makeGatewayMap([]string{"knative-testing/knative-test-gateway", "knative-testing/knative-ingress-gateway"}, nil)),
+				makeGatewayMap([]string{"knative-testing/knative-test-gateway", "knative-testing/" + networking.KnativeIngressGateway}, nil)),
 		},
 		WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
 			Object: ingressWithStatus("no-virtualservice-yet", 1234,
@@ -234,9 +233,8 @@ func TestReconcile(t *testing.T) {
 		},
 		Key: "test-ns/no-virtualservice-yet",
 	}, {
-		Name:                    "observed generation is updated when error is encountered in reconciling, and ingress ready status is unknown",
-		SkipNamespaceValidation: true,
-		WantErr:                 true,
+		Name:    "observed generation is updated when error is encountered in reconciling, and ingress ready status is unknown",
+		WantErr: true,
 		WithReactors: []clientgotesting.ReactionFunc{
 			InduceFailure("update", "virtualservices"),
 		},
@@ -267,7 +265,7 @@ func TestReconcile(t *testing.T) {
 					},
 					OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(ingress("reconcile-failed", 1234))},
 				},
-				Spec: v1alpha3.VirtualServiceSpec{},
+				Spec: istiov1alpha3.VirtualService{},
 			},
 		},
 		WantCreates: []runtime.Object{
@@ -275,24 +273,27 @@ func TestReconcile(t *testing.T) {
 		},
 		WantUpdates: []clientgotesting.UpdateActionImpl{{
 			Object: resources.MakeIngressVirtualService(insertProbe(ingress("reconcile-failed", 1234)),
-				makeGatewayMap([]string{"knative-testing/knative-test-gateway", "knative-testing/knative-ingress-gateway"}, nil)),
+				makeGatewayMap([]string{"knative-testing/knative-test-gateway", "knative-testing/" + networking.KnativeIngressGateway}, nil)),
 		}},
 		WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
 			Object: ingressWithStatus("reconcile-failed", 1234,
 				v1alpha1.IngressStatus{
 					Status: duckv1.Status{
 						Conditions: duckv1.Conditions{{
-							Type:   v1alpha1.IngressConditionLoadBalancerReady,
-							Status: corev1.ConditionTrue,
+							Type:     v1alpha1.IngressConditionLoadBalancerReady,
+							Reason:   v1alpha1.VirtualServiceNotReconciled,
+							Severity: apis.ConditionSeverityError,
+							Message:  "failed to update VirtualService: inducing failure for update virtualservices",
+							Status:   corev1.ConditionFalse,
 						}, {
 							Type:   v1alpha1.IngressConditionNetworkConfigured,
 							Status: corev1.ConditionTrue,
 						}, {
 							Type:     v1alpha1.IngressConditionReady,
-							Status:   corev1.ConditionUnknown,
+							Status:   corev1.ConditionFalse,
 							Severity: apis.ConditionSeverityError,
-							Reason:   NotReconciledReason,
-							Message:  NotReconciledMessage,
+							Reason:   notReconciledReason,
+							Message:  notReconciledMessage,
 						}},
 					},
 				},
@@ -305,8 +306,7 @@ func TestReconcile(t *testing.T) {
 		},
 		Key: "test-ns/reconcile-failed",
 	}, {
-		Name:                    "reconcile VirtualService to match desired one",
-		SkipNamespaceValidation: true,
+		Name: "reconcile VirtualService to match desired one",
 		Objects: []runtime.Object{
 			ingress("reconcile-virtualservice", 1234),
 			&v1alpha3.VirtualService{
@@ -319,7 +319,7 @@ func TestReconcile(t *testing.T) {
 					},
 					OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(ingress("reconcile-virtualservice", 1234))},
 				},
-				Spec: v1alpha3.VirtualServiceSpec{},
+				Spec: istiov1alpha3.VirtualService{},
 			},
 			&v1alpha3.VirtualService{
 				ObjectMeta: metav1.ObjectMeta{
@@ -331,12 +331,12 @@ func TestReconcile(t *testing.T) {
 					},
 					OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(ingress("reconcile-virtualservice", 1234))},
 				},
-				Spec: v1alpha3.VirtualServiceSpec{},
+				Spec: istiov1alpha3.VirtualService{},
 			},
 		},
 		WantUpdates: []clientgotesting.UpdateActionImpl{{
 			Object: resources.MakeIngressVirtualService(insertProbe(ingress("reconcile-virtualservice", 1234)),
-				makeGatewayMap([]string{"knative-testing/knative-test-gateway", "knative-testing/knative-ingress-gateway"}, nil)),
+				makeGatewayMap([]string{"knative-testing/knative-test-gateway", "knative-testing/" + networking.KnativeIngressGateway}, nil)),
 		}},
 		WantCreates: []runtime.Object{
 			resources.MakeMeshVirtualService(insertProbe(ingress("reconcile-virtualservice", 1234))),
@@ -395,18 +395,16 @@ func TestReconcile(t *testing.T) {
 
 	table.Test(t, MakeFactory(func(ctx context.Context, listers *Listers, cmw configmap.Watcher) controller.Reconciler {
 		return &Reconciler{
-			BaseIngressReconciler: &BaseIngressReconciler{
-				Base:                 reconciler.NewBase(ctx, controllerAgentName, cmw),
-				VirtualServiceLister: listers.GetVirtualServiceLister(),
-				GatewayLister:        listers.GetGatewayLister(),
-				Finalizer:            ingressFinalizer,
-				ConfigStore: &testConfigStore{
-					config: ReconcilerTestConfig(),
-				},
-				StatusManager: &fakeStatusManager{
-					FakeIsReady: func(ia v1alpha1.IngressAccessor, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
-						return true, nil
-					},
+			Base:                 reconciler.NewBase(ctx, controllerAgentName, cmw),
+			virtualServiceLister: listers.GetVirtualServiceLister(),
+			gatewayLister:        listers.GetGatewayLister(),
+			finalizer:            ingressFinalizer,
+			configStore: &testConfigStore{
+				config: ReconcilerTestConfig(),
+			},
+			statusManager: &fakeStatusManager{
+				FakeIsReady: func(ia *v1alpha1.Ingress, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
+					return true, nil
 				},
 			},
 			ingressLister: listers.GetIngressLister(),
@@ -421,20 +419,20 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		Objects: []runtime.Object{
 			ingressWithTLS("reconciling-ingress", 1234, ingressTLS),
 			// No Gateway servers match the given TLS of Ingress.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer}),
 			originSecret("istio-system", "secret0"),
 		},
 		WantCreates: []runtime.Object{
 			// The creation of gateways are triggered when setting up the test.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer}),
 
 			resources.MakeMeshVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLS))),
 			resources.MakeIngressVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLS)),
-				makeGatewayMap([]string{"knative-testing/knative-ingress-gateway"}, nil)),
+				makeGatewayMap([]string{"knative-testing/" + networking.KnativeIngressGateway}, nil)),
 		},
 		WantUpdates: []clientgotesting.UpdateActionImpl{{
 			// ingressTLSServer needs to be added into Gateway.
-			Object: gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{ingressTLSServer, irrelevantServer}),
+			Object: gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{ingressTLSServer, irrelevantServer}),
 		}},
 		WantPatches: []clientgotesting.PatchActionImpl{
 			patchAddFinalizerAction("reconciling-ingress", ingressFinalizer),
@@ -479,13 +477,12 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		WantEvents: []string{
 			Eventf(corev1.EventTypeNormal, "Created", "Created VirtualService %q", "reconciling-ingress-mesh"),
 			Eventf(corev1.EventTypeNormal, "Created", "Created VirtualService %q", "reconciling-ingress"),
-			Eventf(corev1.EventTypeNormal, "Updated", "Updated Gateway %s/%s", system.Namespace(), "knative-ingress-gateway"),
+			Eventf(corev1.EventTypeNormal, "Updated", "Updated Gateway %s/%s", system.Namespace(), networking.KnativeIngressGateway),
 			Eventf(corev1.EventTypeNormal, "Updated", "Updated status for Ingress %q", "reconciling-ingress"),
 		},
 		Key: "test-ns/reconciling-ingress",
 	}, {
-		Name:                    "No preinstalled Gateways",
-		SkipNamespaceValidation: true,
+		Name: "No preinstalled Gateways",
 		Objects: []runtime.Object{
 			ingressWithTLS("reconciling-ingress", 1234, ingressTLS),
 			originSecret("istio-system", "secret0"),
@@ -493,7 +490,7 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		WantCreates: []runtime.Object{
 			resources.MakeMeshVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLS))),
 			resources.MakeIngressVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLS)),
-				makeGatewayMap([]string{"knative-testing/knative-ingress-gateway"}, nil)),
+				makeGatewayMap([]string{"knative-testing/" + networking.KnativeIngressGateway}, nil)),
 		},
 		WantPatches: []clientgotesting.PatchActionImpl{
 			patchAddFinalizerAction("reconciling-ingress", ingressFinalizer),
@@ -515,8 +512,8 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 							Type:     v1alpha1.IngressConditionReady,
 							Status:   corev1.ConditionUnknown,
 							Severity: apis.ConditionSeverityError,
-							Reason:   NotReconciledReason,
-							Message:  NotReconciledMessage,
+							Reason:   notReconciledReason,
+							Message:  notReconciledMessage,
 						}},
 					},
 				},
@@ -525,7 +522,7 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		WantEvents: []string{
 			Eventf(corev1.EventTypeNormal, "Created", "Created VirtualService %q", "reconciling-ingress-mesh"),
 			Eventf(corev1.EventTypeNormal, "Created", "Created VirtualService %q", "reconciling-ingress"),
-			Eventf(corev1.EventTypeWarning, "InternalError", `failed to get Gateway: gateway.networking.istio.io "knative-ingress-gateway" not found`),
+			Eventf(corev1.EventTypeWarning, "InternalError", `failed to get Gateway: gateway.networking.istio.io "%s" not found`, networking.KnativeIngressGateway),
 			Eventf(corev1.EventTypeNormal, "Updated", "Updated status for Ingress %q", "reconciling-ingress"),
 		},
 		// Error should be returned when there is no preinstalled gateways.
@@ -536,20 +533,20 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		SkipNamespaceValidation: true,
 		Objects: []runtime.Object{
 			ingressWithFinalizers("reconciling-ingress", 1234, ingressTLS, []string{ingressFinalizer}),
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer, ingressTLSServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer, ingressTLSServer}),
 		},
 		WantCreates: []runtime.Object{
 			// The creation of gateways are triggered when setting up the test.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer, ingressTLSServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer, ingressTLSServer}),
 		},
 		WantUpdates: []clientgotesting.UpdateActionImpl{{
-			Object: gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer}),
+			Object: gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer}),
 		}, {
 			// Finalizer should be removed.
 			Object: ingressWithFinalizers("reconciling-ingress", 1234, ingressTLS, []string{}),
 		}},
 		WantEvents: []string{
-			Eventf(corev1.EventTypeNormal, "Updated", "Updated Gateway %s/%s", system.Namespace(), "knative-ingress-gateway"),
+			Eventf(corev1.EventTypeNormal, "Updated", "Updated Gateway %s/%s", system.Namespace(), networking.KnativeIngressGateway),
 		},
 		Key: "test-ns/reconciling-ingress",
 	}, {
@@ -558,18 +555,18 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		Objects: []runtime.Object{
 			ingressWithTLS("reconciling-ingress", 1234, ingressTLSWithSecretNamespace("knative-serving")),
 			// No Gateway servers match the given TLS of Ingress.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer}),
 			// The namespace (`knative-serving`) of the origin secret is different
 			// from the namespace (`istio-system`) of Istio gateway service.
 			originSecret("knative-serving", "secret0"),
 		},
 		WantCreates: []runtime.Object{
 			// The creation of gateways are triggered when setting up the test.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer}),
 
 			resources.MakeMeshVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLSWithSecretNamespace("knative-serving")))),
 			resources.MakeIngressVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLSWithSecretNamespace("knative-serving"))),
-				makeGatewayMap([]string{"knative-testing/knative-ingress-gateway"}, nil)),
+				makeGatewayMap([]string{"knative-testing/" + networking.KnativeIngressGateway}, nil)),
 
 			// The secret copy under istio-system.
 			secret("istio-system", targetSecretName, map[string]string{
@@ -579,7 +576,7 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		},
 		WantUpdates: []clientgotesting.UpdateActionImpl{{
 			// ingressTLSServer with the name of the secret copy needs to be added into Gateway.
-			Object: gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{*withCredentialName(ingressTLSServer.DeepCopy(), targetSecretName), irrelevantServer}),
+			Object: gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{withCredentialName(deepCopy(ingressTLSServer), targetSecretName), irrelevantServer}),
 		}},
 		WantPatches: []clientgotesting.PatchActionImpl{
 			patchAddFinalizerAction("reconciling-ingress", ingressFinalizer),
@@ -625,7 +622,7 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 			Eventf(corev1.EventTypeNormal, "Created", "Created VirtualService %q", "reconciling-ingress-mesh"),
 			Eventf(corev1.EventTypeNormal, "Created", "Created VirtualService %q", "reconciling-ingress"),
 			Eventf(corev1.EventTypeNormal, "Created", "Created Secret %s/%s", "istio-system", targetSecretName),
-			Eventf(corev1.EventTypeNormal, "Updated", "Updated Gateway %s/%s", system.Namespace(), "knative-ingress-gateway"),
+			Eventf(corev1.EventTypeNormal, "Updated", "Updated Gateway %s/%s", system.Namespace(), networking.KnativeIngressGateway),
 			Eventf(corev1.EventTypeNormal, "Updated", "Updated status for Ingress %q", "reconciling-ingress"),
 		},
 		Key: "test-ns/reconciling-ingress",
@@ -635,7 +632,7 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		Objects: []runtime.Object{
 			ingressWithTLS("reconciling-ingress", 1234, ingressTLSWithSecretNamespace("knative-serving")),
 
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{*withCredentialName(ingressTLSServer.DeepCopy(), targetSecretName), irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{withCredentialName(deepCopy(ingressTLSServer), targetSecretName), irrelevantServer}),
 			// The origin secret.
 			originSecret("knative-serving", "secret0"),
 
@@ -659,10 +656,10 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		},
 		WantCreates: []runtime.Object{
 			// The creation of gateways are triggered when setting up the test.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{*withCredentialName(ingressTLSServer.DeepCopy(), targetSecretName), irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{withCredentialName(deepCopy(ingressTLSServer), targetSecretName), irrelevantServer}),
 			resources.MakeMeshVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLSWithSecretNamespace("knative-serving")))),
 			resources.MakeIngressVirtualService(insertProbe(ingressWithTLS("reconciling-ingress", 1234, ingressTLSWithSecretNamespace("knative-serving"))),
-				makeGatewayMap([]string{"knative-testing/knative-ingress-gateway"}, nil)),
+				makeGatewayMap([]string{"knative-testing/" + networking.KnativeIngressGateway}, nil)),
 		},
 		WantUpdates: []clientgotesting.UpdateActionImpl{{
 			Object: &corev1.Secret{
@@ -736,12 +733,12 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		Objects: []runtime.Object{
 			ingressWithTLSClusterLocal("reconciling-ingress", 1234, ingressTLS),
 			// No Gateway servers match the given TLS of Ingress.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer}),
 			originSecret("istio-system", "secret0"),
 		},
 		WantCreates: []runtime.Object{
 			// The creation of gateways are triggered when setting up the test.
-			gateway("knative-ingress-gateway", system.Namespace(), []v1alpha3.Server{irrelevantServer}),
+			gateway(networking.KnativeIngressGateway, system.Namespace(), []*istiov1alpha3.Server{irrelevantServer}),
 			resources.MakeMeshVirtualService(insertProbe(ingressWithTLSClusterLocal("reconciling-ingress", 1234, ingressTLS))),
 		},
 		WantStatusUpdates: []clientgotesting.UpdateActionImpl{{
@@ -791,39 +788,37 @@ func TestReconcile_EnableAutoTLS(t *testing.T) {
 		// originally generated by kubernetes code generator (i.e. `gatewaies`), we have to
 		// explicitly create gateways when setting up the test per suggestion
 		// https://knative.dev/serving/blob/a6852fc3b6cdce72b99c5d578dd64f2e03dabb8b/vendor/k8s.io/client-go/testing/fixture.go#L292
-		gateways := getGatewaysFromObjects(listers.GetSharedObjects())
+		gateways := getGatewaysFromObjects(listers.GetIstioObjects())
 		for _, gateway := range gateways {
-			fakesharedclient.Get(ctx).NetworkingV1alpha3().Gateways(gateway.Namespace).Create(gateway)
+			fakeistioclient.Get(ctx).NetworkingV1alpha3().Gateways(gateway.Namespace).Create(gateway)
 		}
 
 		return &Reconciler{
-			BaseIngressReconciler: &BaseIngressReconciler{
-				Base:                 reconciler.NewBase(ctx, controllerAgentName, cmw),
-				VirtualServiceLister: listers.GetVirtualServiceLister(),
-				GatewayLister:        listers.GetGatewayLister(),
-				SecretLister:         listers.GetSecretLister(),
-				Tracker:              &NullTracker{},
-				Finalizer:            ingressFinalizer,
-				// Enable reconciling gateway.
-				ConfigStore: &testConfigStore{
-					config: &config.Config{
-						Istio: &config.Istio{
-							IngressGateways: []config.Gateway{{
-								Namespace:  system.Namespace(),
-								Name:       "knative-ingress-gateway",
-								ServiceURL: pkgnet.GetServiceHostname("istio-ingressgateway", "istio-system"),
-							}},
-						},
-						Network: &network.Config{
-							AutoTLS:      true,
-							HTTPProtocol: network.HTTPDisabled,
-						},
+			Base:                 reconciler.NewBase(ctx, controllerAgentName, cmw),
+			virtualServiceLister: listers.GetVirtualServiceLister(),
+			gatewayLister:        listers.GetGatewayLister(),
+			secretLister:         listers.GetSecretLister(),
+			tracker:              &NullTracker{},
+			finalizer:            ingressFinalizer,
+			// Enable reconciling gateway.
+			configStore: &testConfigStore{
+				config: &config.Config{
+					Istio: &config.Istio{
+						IngressGateways: []config.Gateway{{
+							Namespace:  system.Namespace(),
+							Name:       networking.KnativeIngressGateway,
+							ServiceURL: pkgnet.GetServiceHostname("istio-ingressgateway", "istio-system"),
+						}},
+					},
+					Network: &network.Config{
+						AutoTLS:      true,
+						HTTPProtocol: network.HTTPDisabled,
 					},
 				},
-				StatusManager: &fakeStatusManager{
-					FakeIsReady: func(ia v1alpha1.IngressAccessor, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
-						return true, nil
-					},
+			},
+			statusManager: &fakeStatusManager{
+				FakeIsReady: func(ia *v1alpha1.Ingress, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
+					return true, nil
 				},
 			},
 			ingressLister: listers.GetIngressLister(),
@@ -841,13 +836,13 @@ func getGatewaysFromObjects(objects []runtime.Object) []*v1alpha3.Gateway {
 	return gateways
 }
 
-func gateway(name, namespace string, servers []v1alpha3.Server) *v1alpha3.Gateway {
+func gateway(name, namespace string, servers []*istiov1alpha3.Server) *v1alpha3.Gateway {
 	return &v1alpha3.Gateway{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      name,
 			Namespace: namespace,
 		},
-		Spec: v1alpha3.GatewaySpec{
+		Spec: istiov1alpha3.Gateway{
 			Servers: servers,
 		},
 	}
@@ -873,11 +868,16 @@ func secret(namespace, name string, labels map[string]string) *corev1.Secret {
 	}
 }
 
-func withCredentialName(tlsServer *v1alpha3.Server, credentialName string) *v1alpha3.Server {
-	tlsServer.TLS.CredentialName = credentialName
+func withCredentialName(tlsServer *istiov1alpha3.Server, credentialName string) *istiov1alpha3.Server {
+	tlsServer.Tls.CredentialName = credentialName
 	return tlsServer
 }
 
+// Open-coded deepCopy since istio.io/api's Server doesn't provide one currently
+func deepCopy(server *istiov1alpha3.Server) *istiov1alpha3.Server {
+	return proto.Clone(server).(*istiov1alpha3.Server)
+}
+
 func ingressTLSWithSecretNamespace(namespace string) []v1alpha1.IngressTLS {
 	result := []v1alpha1.IngressTLS{}
 	for _, tls := range ingressTLS {
@@ -891,7 +891,7 @@ func patchAddFinalizerAction(ingressName, finalizer string) clientgotesting.Patc
 	action := clientgotesting.PatchActionImpl{
 		Name: ingressName,
 	}
-	patch := fmt.Sprintf(`{"metadata":{"finalizers":["%s"],"resourceVersion":"v1"}}`, finalizer)
+	patch := fmt.Sprintf(`{"metadata":{"finalizers":[%q],"resourceVersion":"v1"}}`, finalizer)
 	action.Patch = []byte(patch)
 	return action
 }
@@ -920,7 +920,7 @@ func ReconcilerTestConfig() *config.Config {
 				ServiceURL: pkgnet.GetServiceHostname("test-ingressgateway", "istio-system"),
 			}, {
 				Namespace:  system.Namespace(),
-				Name:       "knative-ingress-gateway",
+				Name:       networking.KnativeIngressGateway,
 				ServiceURL: pkgnet.GetServiceHostname("istio-ingressgateway", "istio-system"),
 			}},
 		},
@@ -1005,8 +1005,8 @@ func newTestSetup(t *testing.T, configs ...*corev1.ConfigMap) (
 	configMapWatcher := &configmap.ManualWatcher{Namespace: system.Namespace()}
 	controller := NewController(ctx, configMapWatcher)
 
-	controller.Reconciler.(*Reconciler).StatusManager = &fakeStatusManager{
-		FakeIsReady: func(ia v1alpha1.IngressAccessor, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
+	controller.Reconciler.(*Reconciler).statusManager = &fakeStatusManager{
+		FakeIsReady: func(ia *v1alpha1.Ingress, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
 			return true, nil
 		},
 	}
@@ -1121,8 +1121,8 @@ func TestGlobalResyncOnUpdateGatewayConfigMap(t *testing.T) {
 	}
 }
 
-func insertProbe(ia v1alpha1.IngressAccessor) v1alpha1.IngressAccessor {
-	ia = ia.DeepCopyObject().(v1alpha1.IngressAccessor)
+func insertProbe(ia *v1alpha1.Ingress) *v1alpha1.Ingress {
+	ia = ia.DeepCopy()
 	resources.InsertProbe(ia)
 	return ia
 }
@@ -1132,15 +1132,15 @@ func TestGlobalResyncOnUpdateNetwork(t *testing.T) {
 
 	grp := errgroup.Group{}
 
-	sharedClient := fakesharedclient.Get(ctx)
+	istioClient := fakeistioclient.Get(ctx)
 
 	h := NewHooks()
 
 	// Check for Gateway created as a signal that syncHandler ran
-	h.OnUpdate(&sharedClient.Fake, "gateways", func(obj runtime.Object) HookResult {
+	h.OnUpdate(&istioClient.Fake, "gateways", func(obj runtime.Object) HookResult {
 		updatedGateway := obj.(*v1alpha3.Gateway)
 		// The expected gateway should include the Istio TLS server.
-		expectedGateway := gateway("knative-test-gateway", system.Namespace(), []v1alpha3.Server{ingressTLSServer})
+		expectedGateway := gateway("knative-test-gateway", system.Namespace(), []*istiov1alpha3.Server{ingressTLSServer})
 		expectedGateway.Spec.Servers = append(expectedGateway.Spec.Servers, ingressHTTPRedirectServer)
 		expectedGateway.Spec.Servers = resources.SortServers(expectedGateway.Spec.Servers)
 
@@ -1198,9 +1198,9 @@ func TestGlobalResyncOnUpdateNetwork(t *testing.T) {
 	// Create a ingress.
 	ingressClient.Create(ingress)
 
-	gatewayClient := sharedClient.NetworkingV1alpha3().Gateways(system.Namespace())
+	gatewayClient := istioClient.NetworkingV1alpha3().Gateways(system.Namespace())
 	// Create a Gateway
-	gatewayClient.Create(gateway("knative-test-gateway", system.Namespace(), []v1alpha3.Server{}))
+	gatewayClient.Create(gateway("knative-test-gateway", system.Namespace(), []*istiov1alpha3.Server{}))
 
 	// Create origin secret. "ns" namespace is the namespace of ingress gateway service.
 	secretClient := fakekubeclient.Get(ctx).CoreV1().Secrets("istio-system")
@@ -1238,9 +1238,9 @@ func makeGatewayMap(publicGateways []string, privateGateways []string) map[v1alp
 }
 
 type fakeStatusManager struct {
-	FakeIsReady func(ia v1alpha1.IngressAccessor, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error)
+	FakeIsReady func(ia *v1alpha1.Ingress, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error)
 }
 
-func (m *fakeStatusManager) IsReady(ia v1alpha1.IngressAccessor, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
+func (m *fakeStatusManager) IsReady(ia *v1alpha1.Ingress, gw map[v1alpha1.IngressVisibility]sets.String) (bool, error) {
 	return m.FakeIsReady(ia, gw)
 }
